==> auth-client-api-0.0.7-20190830.033135-6-sources.jar: com/xforceplus/phoenix/auth/client/model/MsSendAuthStatisticRequest.java <==
package com.xforceplus.phoenix.auth.client.model;

import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.xforceplus.phoenix.auth.client.model.MsSendAuthStatisticRequestObj;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.util.ArrayList;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonInclude;
import static com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL;
import com.fasterxml.jackson.annotation.JsonIgnore;
import javax.validation.constraints.*;

/**
 * 发送认证统计请求参数
 */
@ApiModel(description = "发送认证统计请求参数")

@JsonInclude(NON_NULL)
public class MsSendAuthStatisticRequest {
  @JsonProperty("orgIdList")
  private List<Long> orgIdList = new ArrayList<Long>();

  @JsonProperty("authTabStatus")
  private Integer authTabStatus = null;

  @JsonProperty("invoiceList")
  private List<Long> invoiceList = new ArrayList<Long>();

  @JsonProperty("paramRequests")
  private List<MsSendAuthStatisticRequestObj> paramRequests = new ArrayList<MsSendAuthStatisticRequestObj>();

  @JsonProperty("tenantCode")
  private String tenantCode = null;

  @JsonProperty("tenantName")
  private String tenantName = null;

  @JsonProperty("sysUserId")
  private Long sysUserId = null;

  @JsonProperty("sysUserName")
  private String sysUserName = null;

  @JsonProperty("purchaserGroupId")
  private Long purchaserGroupId = null;

  @JsonIgnore
  public MsSendAuthStatisticRequest orgIdList(List<Long> orgIdList) {
    this.orgIdList = orgIdList;
    return this;
  }

  public MsSendAuthStatisticRequest addOrgIdListItem(Long orgIdListItem) {
    this.orgIdList.add(orgIdListItem);
    return this;
  }

   /**
   * 组织id集合
   * @return orgIdList
  **/
  @ApiModelProperty(value = "组织id集合")
  public List<Long> getOrgIdList() {
    return orgIdList;
  }

  public void setOrgIdList(List<Long> orgIdList) {
    this.orgIdList = orgIdList;
  }

  @JsonIgnore
  public MsSendAuthStatisticRequest authTabStatus(Integer authTabStatus) {
    this.authTabStatus = authTabStatus;
    return this;
  }

   /**
   * 认证tab值：1-底账未认证，2-传统未认证，3-退税未认证，4-代理出口退税
   * @return authTabStatus
  **/
  @ApiModelProperty(value = "认证tab值：1-底账未认证，2-传统未认证，3-退税未认证，4-代理出口退税")
  public Integer getAuthTabStatus() {
    return authTabStatus;
  }

  public void setAuthTabStatus(Integer authTabStatus) {
    this.authTabStatus = authTabStatus;
  }

  @JsonIgnore
  public MsSendAuthStatisticRequest invoiceList(List<Long> invoiceList) {
    this.invoiceList = invoiceList;
    return this;
  }

  public MsSendAuthStatisticRequest addInvoiceListItem(Long invoiceListItem) {
    this.invoiceList.add(invoiceListItem);
    return this;
  }

   /**
   * 发票id集合(传统认证)
   * @return invoiceList
  **/
  @ApiModelProperty(value = "发票id集合(传统认证)")
  public List<Long> getInvoiceList() {
    return invoiceList;
  }

  public void setInvoiceList(List<Long> invoiceList) {
    this.invoiceList = invoiceList;
  }

  @JsonIgnore
  public MsSendAuthStatisticRequest paramRequests(List<MsSendAuthStatisticRequestObj> paramRequests) {
    this.paramRequests = paramRequests;
    return this;
  }

  public MsSendAuthStatisticRequest addParamRequestsItem(MsSendAuthStatisticRequestObj paramRequestsItem) {
    this.paramRequests.add(paramRequestsItem);
    return this;
  }

   /**
   * 公司，征期，发票id集合(其他认证)
   * @return paramRequests
  **/
  @ApiModelProperty(value = "公司，征期，发票id集合(其他认证)")
  public List<MsSendAuthStatisticRequestObj> getParamRequests() {
    return paramRequests;
  }

  public void setParamRequests(List<MsSendAuthStatisticRequestObj> paramRequests) {
    this.paramRequests = paramRequests;
  }

  @JsonIgnore
  public MsSendAuthStatisticRequest tenantCode(String tenantCode) {
    this.tenantCode = tenantCode;
    return this;
  }

   /**
   * 集团code
   * @return tenantCode
  **/
  @ApiModelProperty(value = "集团code")
  public String getTenantCode() {
    return tenantCode;
  }

  public void setTenantCode(String tenantCode) {
    this.tenantCode = tenantCode;
  }

  @JsonIgnore
  public MsSendAuthStatisticRequest tenantName(String tenantName) {
    this.tenantName = tenantName;
    return this;
  }

   /**
   * 集团名称
   * @return tenantName
  **/
  @ApiModelProperty(value = "集团名称")
  public String getTenantName() {
    return tenantName;
  }

  public void setTenantName(String tenantName) {
    this.tenantName = tenantName;
  }

  @JsonIgnore
  public MsSendAuthStatisticRequest sysUserId(Long sysUserId) {
    this.sysUserId = sysUserId;
    return this;
  }

   /**
   * 用户id
   * @return sysUserId
  **/
  @ApiModelProperty(value = "用户id")
  public Long getSysUserId() {
    return sysUserId;
  }

  public void setSysUserId(Long sysUserId) {
    this.sysUserId = sysUserId;
  }

  @JsonIgnore
  public MsSendAuthStatisticRequest sysUserName(String sysUserName) {
    this.sysUserName = sysUserName;
    return this;
  }

   /**
   * 用户名
   * @return sysUserName
  **/
  @ApiModelProperty(value = "用户名")
  public String getSysUserName() {
    return sysUserName;
  }

  public void setSysUserName(String sysUserName) {
    this.sysUserName = sysUserName;
  }

  @JsonIgnore
  public MsSendAuthStatisticRequest purchaserGroupId(Long purchaserGroupId) {
    this.purchaserGroupId = purchaserGroupId;
    return this;
  }

   /**
   * 集团id
   * @return purchaserGroupId
  **/
  @ApiModelProperty(value = "集团id")
  public Long getPurchaserGroupId() {
    return purchaserGroupId;
  }

  public void setPurchaserGroupId(Long purchaserGroupId) {
    this.purchaserGroupId = purchaserGroupId;
  }


  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    MsSendAuthStatisticRequest sendAuthStatisticRequest = (MsSendAuthStatisticRequest) o;
    return Objects.equals(this.orgIdList, sendAuthStatisticRequest.orgIdList) &&
        Objects.equals(this.authTabStatus, sendAuthStatisticRequest.authTabStatus) &&
        Objects.equals(this.invoiceList, sendAuthStatisticRequest.invoiceList) &&
        Objects.equals(this.paramRequests, sendAuthStatisticRequest.paramRequests) &&
        Objects.equals(this.tenantCode, sendAuthStatisticRequest.tenantCode) &&
        Objects.equals(this.tenantName, sendAuthStatisticRequest.tenantName) &&
        Objects.equals(this.sysUserId, sendAuthStatisticRequest.sysUserId) &&
        Objects.equals(this.sysUserName, sendAuthStatisticRequest.sysUserName) &&
        Objects.equals(this.purchaserGroupId, sendAuthStatisticRequest.purchaserGroupId);
  }

  @Override
  public int hashCode() {
    return Objects.hash(orgIdList, authTabStatus, invoiceList, paramRequests, tenantCode, tenantName, sysUserId, sysUserName, purchaserGroupId);
  }


  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class MsSendAuthStatisticRequest {\n");
    
    sb.append("    orgIdList: ").append(toIndentedString(orgIdList)).append("\n");
    sb.append("    authTabStatus: ").append(toIndentedString(authTabStatus)).append("\n");
    sb.append("    invoiceList: ").append(toIndentedString(invoiceList)).append("\n");
    sb.append("    paramRequests: ").append(toIndentedString(paramRequests)).append("\n");
    sb.append("    tenantCode: ").append(toIndentedString(tenantCode)).append("\n");
    sb.append("    tenantName: ").append(toIndentedString(tenantName)).append("\n");
    sb.append("    sysUserId: ").append(toIndentedString(sysUserId)).append("\n");
    sb.append("    sysUserName: ").append(toIndentedString(sysUserName)).append("\n");
    sb.append("    purchaserGroupId: ").append(toIndentedString(purchaserGroupId)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }

}

==> auth-client-api-0.0.8-20201009.070551-12-sources.jar: com/xforceplus/phoenix/auth/client/model/MsSendAuthStatisticRequest.java <==
package com.xforceplus.phoenix.auth.client.model;

import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.xforceplus.phoenix.auth.client.model.MsSendAuthStatisticRequestObj;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.util.ArrayList;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonInclude;
import static com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL;
import com.fasterxml.jackson.annotation.JsonIgnore;
import javax.validation.constraints.*;

/**
 * 发送认证统计请求参数
 */
@ApiModel(description = "发送认证统计请求参数")

@JsonInclude(NON_NULL)
public class MsSendAuthStatisticRequest {
  @JsonProperty("orgIdList")
  private List<Long> orgIdList = new ArrayList<Long>();

  @JsonProperty("authTabStatus")
  private Integer authTabStatus = null;

  @JsonProperty("authUse")
  private Integer authUse = null;

  @JsonProperty("invoiceList")
  private List<Long> invoiceList = new ArrayList<Long>();

  @JsonProperty("paramRequests")
  private List<MsSendAuthStatisticRequestObj> paramRequests = new ArrayList<MsSendAuthStatisticRequestObj>();

  @JsonProperty("tenantCode")
  private String tenantCode = null;

  @JsonProperty("tenantName")
  private String tenantName = null;

  @JsonProperty("sysUserId")
  private Long sysUserId = null;

  @JsonProperty("sysUserName")
  private String sysUserName = null;

  @JsonProperty("purchaserGroupId")
  private Long purchaserGroupId = null;

  @JsonIgnore
  public MsSendAuthStatisticRequest orgIdList(List<Long> orgIdList) {
    this.orgIdList = orgIdList;
    return this;
  }

  public MsSendAuthStatisticRequest addOrgIdListItem(Long orgIdListItem) {
    this.orgIdList.add(orgIdListItem);
    return this;
  }

   /**
   * 组织id集合
   * @return orgIdList
  **/
  @ApiModelProperty(value = "组织id集合")
  public List<Long> getOrgIdList() {
    return orgIdList;
  }

  public void setOrgIdList(List<Long> orgIdList) {
    this.orgIdList = orgIdList;
  }

  @JsonIgnore
  public MsSendAuthStatisticRequest authTabStatus(Integer authTabStatus) {
    this.authTabStatus = authTabStatus;
    return this;
  }

   /**
   * 认证tab值：1-底账未认证，2-传统未认证，3-退税未认证，4-代理出口退税
   * @return authTabStatus
  **/
  @ApiModelProperty(value = "认证tab值：1-底账未认证，2-传统未认证，3-退税未认证，4-代理出口退税")
  public Integer getAuthTabStatus() {
    return authTabStatus;
  }

  public void setAuthTabStatus(Integer authTabStatus) {
    this.authTabStatus = authTabStatus;
  }

  @JsonIgnore
  public MsSendAuthStatisticRequest authUse(Integer authUse) {
    this.authUse = authUse;
    return this;
  }

   /**
   * 用途:1-抵扣勾选(默认),2-不抵扣勾选,3-出口转内销抵扣勾选,4-出口转内销不抵扣勾选,10-抵扣撤销勾选,20-不抵扣撤销勾选
   * @return authUse
  **/
  @ApiModelProperty(value = "用途:1-抵扣勾选(默认),2-不抵扣勾选,3-出口转内销抵扣勾选,4-出口转内销不抵扣勾选,10-抵扣撤销勾选,20-不抵扣撤销勾选")
  public Integer getAuthUse() {
    return authUse;
  }

  public void setAuthUse(Integer authUse) {
    this.authUse = authUse;
  }

  @JsonIgnore
  public MsSendAuthStatisticRequest invoiceList(List<Long> invoiceList) {
    this.invoiceList = invoiceList;
    return this;
  }

  public MsSendAuthStatisticRequest addInvoiceListItem(Long invoiceListItem) {
    this.invoiceList.add(invoiceListItem);
    return this;
  }

   /**
   * 发票id集合(传统认证)
   * @return invoiceList
  **/
  @ApiModelProperty(value = "发票id集合(传统认证)")
  public List<Long> getInvoiceList() {
    return invoiceList;
  }

  public void setInvoiceList(List<Long> invoiceList) {
    this.invoiceList = invoiceList;
  }

  @JsonIgnore
  public MsSendAuthStatisticRequest paramRequests(List<MsSendAuthStatisticRequestObj> paramRequests) {
    this.paramRequests = paramRequests;
    return this;
  }

  public MsSendAuthStatisticRequest addParamRequestsItem(MsSendAuthStatisticRequestObj paramRequestsItem) {
    this.paramRequests.add(paramRequestsItem);
    return this;
  }

   /**
   * 公司，征期，发票id集合(其他认证)
   * @return paramRequests
  **/
  @ApiModelProperty(value = "公司，征期，发票id集合(其他认证)")
  public List<MsSendAuthStatisticRequestObj> getParamRequests() {
    return paramRequests;
  }

  public void setParamRequests(List<MsSendAuthStatisticRequestObj> paramRequests) {
    this.paramRequests = paramRequests;
  }

  @JsonIgnore
  public MsSendAuthStatisticRequest tenantCode(String tenantCode) {
    this.tenantCode = tenantCode;
    return this;
  }

   /**
   * 集团code
   * @return tenantCode
  **/
  @ApiModelProperty(value = "集团code")
  public String getTenantCode() {
    return tenantCode;
  }

  public void setTenantCode(String tenantCode) {
    this.tenantCode = tenantCode;
  }

  @JsonIgnore
  public MsSendAuthStatisticRequest tenantName(String tenantName) {
    this.tenantName = tenantName;
    return this;
  }

   /**
   * 集团名称
   * @return tenantName
  **/
  @ApiModelProperty(value = "集团名称")
  public String getTenantName() {
    return tenantName;
  }

  public void setTenantName(String tenantName) {
    this.tenantName = tenantName;
  }

  @JsonIgnore
  public MsSendAuthStatisticRequest sysUserId(Long sysUserId) {
    this.sysUserId = sysUserId;
    return this;
  }

   /**
   * 用户id
   * @return sysUserId
  **/
  @ApiModelProperty(value = "用户id")
  public Long getSysUserId() {
    return sysUserId;
  }

  public void setSysUserId(Long sysUserId) {
    this.sysUserId = sysUserId;
  }

  @JsonIgnore
  public MsSendAuthStatisticRequest sysUserName(String sysUserName) {
    this.sysUserName = sysUserName;
    return this;
  }

   /**
   * 用户名
   * @return sysUserName
  **/
  @ApiModelProperty(value = "用户名")
  public String getSysUserName() {
    return sysUserName;
  }

  public void setSysUserName(String sysUserName) {
    this.sysUserName = sysUserName;
  }

  @JsonIgnore
  public MsSendAuthStatisticRequest purchaserGroupId(Long purchaserGroupId) {
    this.purchaserGroupId = purchaserGroupId;
    return this;
  }

   /**
   * 集团id
   * @return purchaserGroupId
  **/
  @ApiModelProperty(value = "集团id")
  public Long getPurchaserGroupId() {
    return purchaserGroupId;
  }

  public void setPurchaserGroupId(Long purchaserGroupId) {
    this.purchaserGroupId = purchaserGroupId;
  }


  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    MsSendAuthStatisticRequest sendAuthStatisticRequest = (MsSendAuthStatisticRequest) o;
    return Objects.equals(this.orgIdList, sendAuthStatisticRequest.orgIdList) &&
        Objects.equals(this.authTabStatus, sendAuthStatisticRequest.authTabStatus) &&
        Objects.equals(this.authUse, sendAuthStatisticRequest.authUse) &&
        Objects.equals(this.invoiceList, sendAuthStatisticRequest.invoiceList) &&
        Objects.equals(this.paramRequests, sendAuthStatisticRequest.paramRequests) &&
        Objects.equals(this.tenantCode, sendAuthStatisticRequest.tenantCode) &&
        Objects.equals(this.tenantName, sendAuthStatisticRequest.tenantName) &&
        Objects.equals(this.sysUserId, sendAuthStatisticRequest.sysUserId) &&
        Objects.equals(this.sysUserName, sendAuthStatisticRequest.sysUserName) &&
        Objects.equals(this.purchaserGroupId, sendAuthStatisticRequest.purchaserGroupId);
  }

  @Override
  public int hashCode() {
    return Objects.hash(orgIdList, authTabStatus, authUse, invoiceList, paramRequests, tenantCode, tenantName, sysUserId, sysUserName, purchaserGroupId);
  }


  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class MsSendAuthStatisticRequest {\n");
    
    sb.append("    orgIdList: ").append(toIndentedString(orgIdList)).append("\n");
    sb.append("    authTabStatus: ").append(toIndentedString(authTabStatus)).append("\n");
    sb.append("    authUse: ").append(toIndentedString(authUse)).append("\n");
    sb.append("    invoiceList: ").append(toIndentedString(invoiceList)).append("\n");
    sb.append("    paramRequests: ").append(toIndentedString(paramRequests)).append("\n");
    sb.append("    tenantCode: ").append(toIndentedString(tenantCode)).append("\n");
    sb.append("    tenantName: ").append(toIndentedString(tenantName)).append("\n");
    sb.append("    sysUserId: ").append(toIndentedString(sysUserId)).append("\n");
    sb.append("    sysUserName: ").append(toIndentedString(sysUserName)).append("\n");
    sb.append("    purchaserGroupId: ").append(toIndentedString(purchaserGroupId)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }

}
